==> fredquery-0.0.24.tar.gz: fredquery-0.0.24/tests/x.sh <==
#¡ sh
set -ex

fredcategories --categories --file /tmp/categories.csv 
fredcategories --series --categoryid 32455 --file /tmp/cseries32455.csv 
fredcategories --series --seriesid 00XALCATM086NEST --file \
       /tmp/00XALCATM086NEST_series.csv 
fredcategories --observations --directory /tmp --categoryid 32455
#    fredcategories --observations --directory /tmp --seriesid
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv > /dev/null
set -x


fredreleases --releases --file /tmp/releases.csv
fredreleases --series --releaseid 9 --file /tmp/rseries9.csv
fredreleases --series --seriesid ALLQ13A12MINR --file \
     /tmp/ALLQ13A12MINR_series.csv
fredreleases --observations --directory /tmp --releaseid 9
#    fredreleases --observations --directory /tmp --seriesid 
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x


fredsources --sources  --file /tmp/sources.csv
fredsources --releases --sourceid 69 --file /tmp/sreleases69.csv
#    fredsources --releases --file /tmp/sreleases.csv
#    fredsources --sources --directory /tmp
fredsources --observations --sourceid 69 --directory /tmp
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x

fredseries --series     --seriesid AKIRPD --file /tmp/AKIRPD_series.csv
fredseries --categories --seriesid AKIRPD --file /tmp/AKIRPD_categories.csv
fredseries --releases   --seriesid AKIRPD --file /tmp/AKIRPD_releases.csv
fredseries --sources    --seriesid AKIRPD --file /tmp/AKIRPD_sources.csv
fredseries --tags       --seriesid AKIRPD --file /tmp/AKIRPD_tags.csv
fredseries --updates    --seriesid AKIRPD --file /tmp/AKIRPD_updates.csv
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x

fredtags --tags   --file /tmp/tags.csv
fredtags --series --tagname price --file /tmp/tseriesprice.csv
fredtags --series --seriesid ALLQ14ICNR --file /tmp/ALLQ14ICNR_series.csv
fredtags --observations --tagname price --directory /tmp
#    fredtags --observations --directory /tmp --seriesid 
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x

==> fredquery-0.0.54.tar.gz: fredquery-0.0.54/tests/x.sh <==
#¡ sh
set -ex

fredcategories --categories --file /tmp/categories.csv 
fredcategories --categories --showcategories
fredcategories --series --categoryid 32455 --file /tmp/cseries32455.csv 
fredcategories --series --categoryid 32455 --showseries
fredcategories --observations --directory /tmp --categoryid 32455
#    fredcategories --observations --directory /tmp --seriesid
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv > /dev/null
set -x


fredreleases --releases --file /tmp/releases.csv
fredreleases --releases --showreleases
fredreleases --series --releaseid 365 --file /tmp/rseries365.csv
fredreleases --series --releaseid 365 --showseries
fredreleases --observations --directory /tmp --releaseid 9
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x

fredseries --series     --seriesid AKIRPD --file /tmp/AKIRPD_series.csv
fredseries --observations --seriesid AKIRPD --directory /tmp
fredseries --categories --seriesid AKIRPD --file /tmp/AKIRPD_categories.csv
fredseries --releases   --seriesid AKIRPD --file /tmp/AKIRPD_releases.csv
fredseries --sources    --seriesid AKIRPD --file /tmp/AKIRPD_sources.csv
fredseries --tags       --seriesid AKIRPD --file /tmp/AKIRPD_tags.csv
fredseries --updates    --seriesid AKIRPD --file /tmp/AKIRPD_updates.csv
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x

fredsources --sources  --file /tmp/sources.csv
fredsources --sources  --showsources
fredsources --releases --sourceid 57 --file /tmp/sreleases57.csv
fredsources --releases --sourceid 57 --showreleases
fredsources --series --sourceid 57 --file /tmp/Source57.csv
fredsources --series --sourceid 57 --showseries
fredsources --observations --sourceid 57 --directory /tmp
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x


fredtags --tags   --file /tmp/tags.csv
fredtags --tags   --showtags
fredtags --series --tagname inflation --file /tmp/tseriesinflation.csv
fredtags --series --tagname inflation --showseries
fredtags --observations --tagname inflation --directory /tmp
set +x
ls /private/tmp/[0-9A-Z]*.csv | wc -l
rm /private/tmp/[0-9A-Z]*.csv >/dev/null
set -x
